@@ -6,9 +6,9 @@ use Data::Dumper;
 use File::Temp;
 use Logging::Simple;
 use Test::BrewBuild::BrewCommands;
-use Test::BrewBuild::Plugin;
+use Plugin::Simple default => 'Test::BrewBuild::Plugin::DefaultExec';
 
-our $VERSION = '0.06';
+our $VERSION = '1.00';
 
 my $log;
 my $bcmd;
@@ -22,16 +22,17 @@ sub new {
     $log->_7("in new(), constructing " . __PACKAGE__ . " object");
 
     $bcmd = Test::BrewBuild::BrewCommands->new($log);
-    my $exec_plugin_name = $args{plugin} ? $args{plugin} : $ENV{TBB_PLUGIN};
 
-    $log->_7("plugin param set to: $exec_plugin_name") if $exec_plugin_name;
+    my $plugin = $args{plugin} ? $args{plugin} : $ENV{TBB_PLUGIN};
 
-    $exec_plugin_name = $self->plugin($exec_plugin_name);
+    $log->_7("plugin param set to: " . defined $plugin ? $plugin : 'default');
 
-    my $exec_plugin_sub = $exec_plugin_name .'::brewbuild_exec';
+    $plugin = $self->plugins($plugin, can => ['brewbuild_exec']);
+
+    my $exec_plugin_sub = $plugin .'::brewbuild_exec';
     $self->{exec_plugin} = \&$exec_plugin_sub;
 
-    $log->_7("using plugin $exec_plugin_name");
+    $log->_7("using plugin $plugin");
 
     return $self;
 }
@@ -59,10 +60,8 @@ sub instance_remove {
 
     my $log = $log->child('instance_remove');
 
-    if ($self->{args}{debug}) {
-        $log->_5("perls installed: " . join ', ', @perls_installed);
-        $log->_5("removing previous installs...");
-    }
+    $log->_5("perls installed: " . join ', ', @perls_installed);
+    $log->_5("removing previous installs...");
 
     my $remove_cmd = $bcmd->remove;
 
@@ -79,7 +78,13 @@ sub instance_remove {
 
         $log->_7("exec'ing $remove_cmd");
 
-        `$remove_cmd $_`;
+        if ($bcmd->is_win) {
+            `$remove_cmd $_ 2>nul`;
+        }
+        else {
+            `$remove_cmd $_ 2>/dev/null`;
+
+        }
     }
 
     $log->_5("removal of existing perl installs complete...");
@@ -95,8 +100,6 @@ sub instance_install {
 
     if ($self->{args}{version}->[0]){
         for my $version (@{ $self->{args}{version} }){
-            $version = $bcmd->version($_);
-
             if (grep { $version eq $_ } @{ $perls_installed }){
                 $log->_5("$version is already installed... skipping");
                 next;
@@ -153,6 +156,7 @@ sub results {
     $log->_7("got " . scalar @ver_results . " results");
 
     my @pass;
+    my $fail = 0;
 
     for (@ver_results){
         my $ver;
@@ -169,15 +173,18 @@ sub results {
         else {
             $log->_7("$ver FAILED...");
             print $_;
-            exit;
+            $fail = 1;
+            last;
         }
 
         $log->_7("$ver :: $res");
         push @pass, "$ver :: $res\n";
     }
 
-    print "\n";
-    print $_ for @pass;
+    if (! $fail) {
+        print "\n";
+        print $_ for @pass;
+    }
 
     $log->_7(__PACKAGE__ ." run finished");
 }
@@ -199,22 +206,25 @@ sub run {
 
     $log->_5("installed perls: " . join ', ', @perls_installed);
 
-    $self->instance_remove(@perls_installed) if $self->{args}{remove};
+    if ($self->{args}{remove}){
+        $self->instance_remove(@perls_installed);
+
+    }
 
     if ($new) {
         $self->instance_install($new, \@perls_available, \@perls_installed);
     }
 
-    $brew_info = $self->brew_info;
     @perls_installed = $self->perls_installed($brew_info);
 
-    if (! @perls_installed) {
+    if (! $perls_installed[0]){
         $log->_0("no perls installed... exiting");
         print "no perls installed... exiting" if $log->level;
-        exit;
+    }
+    else {
+        $self->results();
     }
 
-    $self->results();
 }
 sub exec {
     my $self = shift;
@@ -247,11 +257,23 @@ sub exec {
         $log->_7("versions to run on: $vers");
         $log->_7("exec'ing: $brew exec --with $vers perl $fname");
 
-        return `$brew exec --with $vers perl $fname`;
+        if ($bcmd->is_win){
+            return `$brew exec --with $vers perl $fname 2>nul`;
+
+        }
+        else {
+            return `$brew exec --with $vers perl $fname 2>/dev/null`;
+        }
     }
     else {
         $log->_7("exec'ing: $brew exec perl $fname");
-        return `$brew exec perl $fname`;
+
+        if ($bcmd->is_win) {
+            return `$brew exec perl $fname 2>nul`;
+        }
+        else {
+            return `$brew exec perl $fname 2>/dev/null`;
+        }
     }
 }
 sub brew_info {
